docs.rs failed to build sp1-gpu-tracing-6.4.0
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Visit the last successful build:
sp1-gpu-tracing-6.3.1
sp1-gpu-tracing
Tracing and debugging instrumentation for SP1-GPU.
Provides tracing infrastructure for profiling and debugging the GPU prover, with support for Jaeger telemetry export and detailed timing information.
Usage with Jaeger
# Start Jaeger
# Run with tracing
# View traces at http://localhost:16686
Part of SP1-GPU, the GPU-accelerated prover for SP1.